QcrpluginPlatform class abstract
- Inheritance
-
- Object
- PlatformInterface
- QcrpluginPlatform
- Implementers
Constructors
- QcrpluginPlatform()
- Constructs a QcrpluginPlatform.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getPlatformVersion(
) → Future< String?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
startQcrCapture(
Map< String, dynamic> args) → Future<Map?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ QcrpluginPlatform
-
The default instance of QcrpluginPlatform to use.
getter/setter pair